pub struct SmtpTestContainer { /* private fields */ }Expand description
Reusable Mailpit SMTP/API container.
Implementations
Sourceimpl SmtpTestContainer
impl SmtpTestContainer
Sourcepub async fn start(suite: &TestContainerSuite) -> Self
pub async fn start(suite: &TestContainerSuite) -> Self
Starts or reuses a Mailpit container for the test suite.
Sourcepub fn smtp_address(&self) -> SocketAddr
pub fn smtp_address(&self) -> SocketAddr
Returns the SMTP endpoint host and port.
Sourcepub async fn clear_messages(&self)
pub async fn clear_messages(&self)
Deletes all messages currently stored by Mailpit.
Sourcepub async fn message_count(&self) -> u64
pub async fn message_count(&self) -> u64
Returns the number of messages currently stored by Mailpit.