pub struct ContainerStateLock { /* private fields */ }Expand description
Exclusive filesystem lock guarding one service’s state file.
Hold the lock for the whole read-modify-write cycle. The lock is released when the guard drops.
Implementations
Sourceimpl ContainerStateLock
impl ContainerStateLock
Sourcepub fn acquire(suite: &TestContainerSuite, service: &str) -> Self
pub fn acquire(suite: &TestContainerSuite, service: &str) -> Self
Acquires the exclusive lock for service within suite, blocking until available.
Sourcepub fn load(&self) -> SharedContainerState
pub fn load(&self) -> SharedContainerState
Loads the state file, tolerating a missing or empty file.
Sourcepub fn save(&self, state: &SharedContainerState)
pub fn save(&self, state: &SharedContainerState)
Persists the state file atomically enough for test purposes (write + flush).