pub async fn wait_until<F, Fut>(
timeout: Duration,
interval: Duration,
check: F,
) -> boolExpand description
Polls check until it returns true or timeout elapses.
Returns whether the condition was observed before the deadline. A final attempt is made after the last sleep when the deadline passes between attempts.